@@ -10,9 +10,16 @@
 #ifndef __CM_H_ENV__
 #define __CM_H_ENV__ 1
 
+/* We use pthreads in the cache manager (not LWP) */
 #ifndef AFS_PTHREAD_ENV
 #define AFS_PTHREAD_ENV 1
 #endif
+
+/* Support largefiles by default */
+#ifndef AFS_LARGEFILES
+#define AFS_LARGEFILES 1
+#endif
+
 #include <rx/rx.h>
 #include <afs/vldbint.h>
 #include <afs/afsint.h>
