@@ -10,9 +10,7 @@
 #include <afs/param.h>
 #include <afs/stds.h>
 
-#ifndef DJGPP
 #include <windows.h>
-#endif /* !DJGPP */
 #include <string.h>
 #include <malloc.h>
 #include <osi.h>
@@ -78,34 +76,40 @@ void cm_InitConn(void)
 	    dummyLen = sizeof(DWORD);
 	    code = RegQueryValueEx(parmKey, "ConnDeadTimeout", NULL, NULL,
 				    (BYTE *) &dwValue, &dummyLen);
-	    if (code == ERROR_SUCCESS)
+	    if (code == ERROR_SUCCESS) {
                 ConnDeadtimeout = (unsigned short)dwValue;
-
+                afsi_log("ConnDeadTimeout is %d", ConnDeadtimeout);
+            }
 	    dummyLen = sizeof(DWORD);
 	    code = RegQueryValueEx(parmKey, "HardDeadTimeout", NULL, NULL,
 				    (BYTE *) &dwValue, &dummyLen);
-	    if (code == ERROR_SUCCESS)
+	    if (code == ERROR_SUCCESS) {
                 HardDeadtimeout = (unsigned short)dwValue;
-	    afsi_log("HardDeadTimeout is %d", HardDeadtimeout);
-
+                afsi_log("HardDeadTimeout is %d", HardDeadtimeout);
+            }
 	    dummyLen = sizeof(DWORD);
 	    code = RegQueryValueEx(parmKey, "IdleDeadTimeout", NULL, NULL,
 				    (BYTE *) &dwValue, &dummyLen);
-	    if (code == ERROR_SUCCESS)
+	    if (code == ERROR_SUCCESS) {
                 IdleDeadtimeout = (unsigned short)dwValue;
-	    afsi_log("IdleDeadTimeout is %d", IdleDeadtimeout);
-
+                afsi_log("IdleDeadTimeout is %d", IdleDeadtimeout);
+            }
             RegCloseKey(parmKey);
 	}
 
 	afsi_log("lanmanworkstation : SessTimeout %u", RDRtimeout);
-	if (ConnDeadtimeout == 0)
+	if (ConnDeadtimeout == 0) {
 	    ConnDeadtimeout = (unsigned short) (RDRtimeout / 2);
-	afsi_log("ConnDeadTimeout is %d", ConnDeadtimeout);
-	if (HardDeadtimeout == 0)
+            afsi_log("ConnDeadTimeout is %d", ConnDeadtimeout);
+        }
+	if (HardDeadtimeout == 0) {
 	    HardDeadtimeout = (unsigned short) RDRtimeout;
-	afsi_log("HardDeadTimeout is %d", HardDeadtimeout);
-
+            afsi_log("HardDeadTimeout is %d", HardDeadtimeout);
+        }
+	if (ConnDeadtimeout == 0) {
+	    IdleDeadtimeout = (unsigned short) RDRtimeout;
+            afsi_log("IdleDeadTimeout is %d", IdleDeadtimeout);
+        }
 	osi_EndOnce(&once);
     }
 }
@@ -113,11 +117,7 @@ void cm_InitConn(void)
 void cm_InitReq(cm_req_t *reqp)
 {
 	memset((char *)reqp, 0, sizeof(cm_req_t));
-#ifndef DJGPP
 	reqp->startTime = GetTickCount();
-#else
-        gettimeofday(&reqp->startTime, NULL);
-#endif
 }
 
 static long cm_GetServerList(struct cm_fid *fidp, struct cm_user *userp,
@@ -216,12 +216,7 @@ cm_Analyze(cm_conn_t *connp, cm_user_t *userp, cm_req_t *reqp,
      * and retry */
     
     /* timeleft - get if from reqp the same way as cmXonnByMServers does */
-#ifndef DJGPP
     timeUsed = (GetTickCount() - reqp->startTime) / 1000;
-#else
-    gettimeofday(&now, NULL);
-    timeUsed = sub_time(now, reqp->startTime) / 1000;
-#endif
 	    
     /* leave 5 seconds margin for sleep */
     if (reqp->flags & CM_REQ_NORETRY)
@@ -429,44 +424,30 @@ cm_Analyze(cm_conn_t *connp, cm_user_t *userp, cm_req_t *reqp,
     {       
         char addr[16];
         char *format;
-#ifndef DJGPP
 	DWORD msgID;
-#endif
         switch ( errorCode ) {
         case VNOVOL:
-#ifndef DJGPP
 	    msgID = MSG_SERVER_REPORTS_VNOVOL;
-#endif
             format = "Server %s reported volume %d as not attached.";
             break;
         case VMOVED:
-#ifndef DJGPP
 	    msgID = MSG_SERVER_REPORTS_VMOVED;
-#endif
             format = "Server %s reported volume %d as moved.";
             break;
         case VOFFLINE:
-#ifndef DJGPP
 	    msgID = MSG_SERVER_REPORTS_VOFFLINE;
-#endif
             format = "Server %s reported volume %d as offline.";
             break;
         case VSALVAGE:
-#ifndef DJGPP
 	    msgID = MSG_SERVER_REPORTS_VSALVAGE;
-#endif
             format = "Server %s reported volume %d as needs salvage.";
             break;
         case VNOSERVICE:
-#ifndef DJGPP
 	    msgID = MSG_SERVER_REPORTS_VNOSERVICE;
-#endif
             format = "Server %s reported volume %d as not in service.";
             break;
         case VIO:
-#ifndef DJGPP
 	    msgID = MSG_SERVER_REPORTS_VIO;
-#endif
             format = "Server %s reported volume %d as temporarily unaccessible.";
             break;
         }
@@ -480,9 +461,7 @@ cm_Analyze(cm_conn_t *connp, cm_user_t *userp, cm_req_t *reqp,
                     ((serverp->addr.sin_addr.s_addr & 0xff000000)>> 24)); 
 
             osi_Log2(afsd_logp, format, osi_LogSaveString(afsd_logp,addr), fidp->volume);
-#ifndef DJGPP
             LogEvent(EVENTLOG_WARNING_TYPE, msgID, addr, fidp->volume);
-#endif
         }
 
         /* Mark server offline for this volume */
@@ -584,9 +563,7 @@ cm_Analyze(cm_conn_t *connp, cm_user_t *userp, cm_req_t *reqp,
                      ((serverp->addr.sin_addr.s_addr & 0xff0000)>> 16),
                      ((serverp->addr.sin_addr.s_addr & 0xff000000)>> 24)); 
 
-#ifndef DJGPP
             LogEvent(EVENTLOG_WARNING_TYPE, MSG_RX_HARD_DEAD_TIME_EXCEEDED, addr);
-#endif /* !DJGPP */
 	  
             osi_Log1(afsd_logp, "cm_Analyze: hardDeadTime exceeded addr[%s]",
                      osi_LogSaveString(afsd_logp,addr));
@@ -793,11 +770,9 @@ long cm_ConnByMServers(cm_serverRef_t *serversp, cm_user_t *usersp,
     cm_server_t *tsp;
     long firstError = 0;
     int someBusy = 0, someOffline = 0, allOffline = 1, allBusy = 1, allDown = 1;
+#ifdef SET_RX_TIMEOUTS_TO_TIMELEFT
     long timeUsed, timeLeft, hardTimeLeft;
-#ifdef DJGPP
-    struct timeval now;
-#endif /* DJGPP */        
-
+#endif
     *connpp = NULL;
 
     if (serversp == NULL) {
@@ -805,16 +780,13 @@ long cm_ConnByMServers(cm_serverRef_t *serversp, cm_user_t *usersp,
 	return CM_ERROR_ALLDOWN;
     }
 
-#ifndef DJGPP
+#ifdef SET_RX_TIMEOUTS_TO_TIMELEFT
     timeUsed = (GetTickCount() - reqp->startTime) / 1000;
-#else
-    gettimeofday(&now, NULL);
-    timeUsed = sub_time(now, reqp->startTime) / 1000;
-#endif
         
     /* leave 5 seconds margin of safety */
     timeLeft =  ConnDeadtimeout - timeUsed - 5;
     hardTimeLeft = HardDeadtimeout - timeUsed - 5;
+#endif
 
     lock_ObtainRead(&cm_serverLock);
     for (tsrp = serversp; tsrp; tsrp=tsrp->next) {
@@ -848,6 +820,7 @@ long cm_ConnByMServers(cm_serverRef_t *serversp, cm_user_t *usersp,
                 code = cm_ConnByServer(tsp, usersp, connpp);
                 if (code == 0) {        /* cm_CBS only returns 0 */
                     cm_PutServer(tsp);
+#ifdef SET_RX_TIMEOUTS_TO_TIMELEFT
                     /* Set RPC timeout */
                     if (timeLeft > ConnDeadtimeout)
                         timeLeft = ConnDeadtimeout;
@@ -856,9 +829,10 @@ long cm_ConnByMServers(cm_serverRef_t *serversp, cm_user_t *usersp,
                         hardTimeLeft = HardDeadtimeout;
 
                     lock_ObtainMutex(&(*connpp)->mx);
-                    rx_SetConnDeadTime((*connpp)->callp, timeLeft);
-                    rx_SetConnHardDeadTime((*connpp)->callp, (u_short) hardTimeLeft);
+                    rx_SetConnDeadTime((*connpp)->rxconnp, timeLeft);
+                    rx_SetConnHardDeadTime((*connpp)->rxconnp, (u_short) hardTimeLeft);
                     lock_ReleaseMutex(&(*connpp)->mx);
+#endif
                     return 0;
                 }
                 
@@ -906,7 +880,7 @@ void cm_GCConnections(cm_server_t *serverp)
             cm_PutServer(tcp->serverp);
             cm_ReleaseUser(userp);
             *lcpp = tcp->nextp;
-            rx_DestroyConnection(tcp->callp);
+            rx_DestroyConnection(tcp->rxconnp);
             lock_FinalizeMutex(&tcp->mx);
             free(tcp);
         }
@@ -952,14 +926,14 @@ static void cm_NewRXConnection(cm_conn_t *tcp, cm_ucell_t *ucellp,
         secObjp = rxnull_NewClientSecurityObject();
     }
     osi_assertx(secObjp != NULL, "null rx_securityClass");
-    tcp->callp = rx_NewConnection(serverp->addr.sin_addr.s_addr,
+    tcp->rxconnp = rx_NewConnection(serverp->addr.sin_addr.s_addr,
                                   port,
                                   serviceID,
                                   secObjp,
                                   secIndex);
-    rx_SetConnDeadTime(tcp->callp, ConnDeadtimeout);
-    rx_SetConnHardDeadTime(tcp->callp, HardDeadtimeout);
-    rx_SetConnIdleDeadTime(tcp->callp, IdleDeadtimeout);
+    rx_SetConnDeadTime(tcp->rxconnp, ConnDeadtimeout);
+    rx_SetConnHardDeadTime(tcp->rxconnp, HardDeadtimeout);
+    rx_SetConnIdleDeadTime(tcp->rxconnp, IdleDeadtimeout);
     tcp->ucgen = ucellp->gen;
     if (secObjp)
         rxs_Release(secObjp);   /* Decrement the initial refCount */
@@ -1024,7 +998,7 @@ long cm_ConnByServer(cm_server_t *serverp, cm_user_t *userp, cm_conn_t **connpp)
             else
                 osi_Log0(afsd_logp, "cm_ConnByServer replace connection due to crypt change");
 	    tcp->flags &= ~CM_CONN_FLAG_FORCE_NEW;
-            rx_DestroyConnection(tcp->callp);
+            rx_DestroyConnection(tcp->rxconnp);
             cm_NewRXConnection(tcp, ucellp, serverp);
         }
         lock_ReleaseMutex(&tcp->mx);
@@ -1125,12 +1099,12 @@ long cm_ConnFromVolume(struct cm_volume *volp, unsigned long volid, struct cm_us
 extern struct rx_connection *
 cm_GetRxConn(cm_conn_t *connp)
 {
-    struct rx_connection * rxconn;
+    struct rx_connection * rxconnp;
     lock_ObtainMutex(&connp->mx);
-    rxconn = connp->callp;
-    rx_GetConnection(rxconn);
+    rxconnp = connp->rxconnp;
+    rx_GetConnection(rxconnp);
     lock_ReleaseMutex(&connp->mx);
-    return rxconn;
+    return rxconnp;
 }
 
 void cm_ForceNewConnections(cm_server_t *serverp)
