@@ -18,7 +18,7 @@
 #include "afs/param.h"
 
 RCSID
-    ("$Header: /cvs/openafs/src/afs/VNOPS/afs_vnop_open.c,v 1.11.20.1 2008/05/20 21:59:40 shadow Exp $");
+    ("$Header: /cvs/openafs/src/afs/VNOPS/afs_vnop_open.c,v 1.11.6.2 2008/05/23 14:25:16 shadow Exp $");
 
 #include "afs/sysincludes.h"	/* Standard vendor system headers */
 #include "afsincludes.h"	/* Afs-based standard headers */
@@ -59,12 +59,29 @@ afs_open(struct vcache **avcp, afs_int32 aflags, struct AFS_UCRED *acred)
     afs_Trace2(afs_iclSetp, CM_TRACE_OPEN, ICL_TYPE_POINTER, tvc,
 	       ICL_TYPE_INT32, aflags);
     afs_InitFakeStat(&fakestate);
+
+    AFS_DISCON_LOCK();
+
     code = afs_EvalFakeStat(&tvc, &fakestate, &treq);
     if (code)
 	goto done;
     code = afs_VerifyVCache(tvc, &treq);
     if (code)
 	goto done;
+
+    ObtainReadLock(&tvc->lock);
+
+#ifdef AFS_DISCON_ENV
+    if (AFS_IS_DISCONNECTED && (afs_DCacheMissingChunks(tvc) != 0)) {
+       ReleaseReadLock(&tvc->lock);
+       /*printf("Network is down in afs_open: missing chunks\n");*/
+       code = ENETDOWN;
+       goto done;
+    }
+#endif
+
+    ReleaseReadLock(&tvc->lock);
+
     if (aflags & (FWRITE | FTRUNC))
 	writing = 1;
     else
@@ -181,6 +198,8 @@ afs_open(struct vcache **avcp, afs_int32 aflags, struct AFS_UCRED *acred)
     }	
   done:
     afs_PutFakeStat(&fakestate);
+    AFS_DISCON_UNLOCK();
+
     code = afs_CheckCode(code, &treq, 4);	/* avoid AIX -O bug */
 
     afs_Trace2(afs_iclSetp, CM_TRACE_OPEN, ICL_TYPE_POINTER, tvc,
