@@ -10,14 +10,12 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /cvs/openafs/src/auth/writeconfig.c,v 1.6 2001/08/08 00:03:37 shadow Exp $");
+RCSID
+    ("$Header: /cvs/openafs/src/auth/writeconfig.c,v 1.12.4.2 2007/11/01 16:09:32 shadow Exp $");
 
 #include <afs/pthread_glock.h>
 #include <afs/afsutil.h>
 #include <sys/types.h>
-#ifdef AFS_SUN5_ENV 
-#include <fcntl.h>
-#endif
 #ifdef AFS_NT40_ENV
 #include <winsock2.h>
 #include <fcntl.h>
@@ -30,6 +28,14 @@ RCSID("$Header: /cvs/openafs/src/auth/writeconfig.c,v 1.6 2001/08/08 00:03:37 sh
 #endif
 #include <stdio.h>
 #include <errno.h>
+#include <string.h>
+#ifdef HAVE_FCNTL_H
+#include <fcntl.h>
+#endif
+#ifdef HAVE_UNISTD_H
+#include <unistd.h>
+#endif
+#include <rx/rxkad.h>
 #include "cellconfig.h"
 #include "keys.h"
 
@@ -37,33 +43,36 @@ RCSID("$Header: /cvs/openafs/src/auth/writeconfig.c,v 1.6 2001/08/08 00:03:37 sh
     by acellInfo parm.   Useful only on the server (which describes only one cell).
 */
 
-static VerifyEntries(aci)
-register struct afsconf_cell *aci; {
+static int
+VerifyEntries(register struct afsconf_cell *aci)
+{
     register int i;
     register struct hostent *th;
-    
-    for(i=0;i<aci->numServers;i++) {
+
+    for (i = 0; i < aci->numServers; i++) {
 	if (aci->hostAddr[i].sin_addr.s_addr == 0) {
 	    /* no address spec'd */
 	    if (*(aci->hostName[i]) != 0) {
 		th = gethostbyname(aci->hostName[i]);
 		if (!th) {
-			printf("Host %s not found in host database...\n", aci->hostName[i]);
-			return AFSCONF_FAILURE;
+		    printf("Host %s not found in host database...\n",
+			   aci->hostName[i]);
+		    return AFSCONF_FAILURE;
 		}
-		memcpy(&aci->hostAddr[i].sin_addr, th->h_addr, sizeof(afs_int32));
+		memcpy(&aci->hostAddr[i].sin_addr, th->h_addr,
+		       sizeof(afs_int32));
 	    }
 	    /* otherwise we're deleting this entry */
-	}
-	else {
+	} else {
 	    /* address spec'd, perhaps no name known */
-	    if (aci->hostName[i][0] != 0) continue; /* name known too */
+	    if (aci->hostName[i][0] != 0)
+		continue;	/* name known too */
 	    /* figure out name, if possible */
-	    th = gethostbyaddr((char *)(&aci->hostAddr[i].sin_addr), 4, AF_INET);
+	    th = gethostbyaddr((char *)(&aci->hostAddr[i].sin_addr), 4,
+			       AF_INET);
 	    if (!th) {
 		strcpy(aci->hostName[i], "UNKNOWNHOST");
-	    }
-	    else {
+	    } else {
 		strcpy(aci->hostName[i], th->h_name);
 	    }
 	}
@@ -74,55 +83,53 @@ register struct afsconf_cell *aci; {
 /* Changed the interface to accept the afsconf_dir datastructure.
    This is a handle to the internal cache that is maintained by the bosserver.
    */
-   
-afsconf_SetCellInfo(adir, apath, acellInfo)
-struct afsconf_dir *adir;
-char *apath;
-struct afsconf_cell *acellInfo; 
+
+int
+afsconf_SetCellInfo(struct afsconf_dir *adir, const char *apath, 
+		    struct afsconf_cell *acellInfo)
 {
     afs_int32 code;
 
-    code = afsconf_SetExtendedCellInfo(adir, apath, acellInfo, (char *)0);
+    code = afsconf_SetExtendedCellInfo(adir, apath, acellInfo, NULL);
     return code;
 }
-   
-afsconf_SetExtendedCellInfo(adir, apath, acellInfo, clones)
-    struct afsconf_dir *adir;
-    char *apath;
-    struct afsconf_cell *acellInfo; 
-    char clones[];
+
+int
+afsconf_SetExtendedCellInfo(struct afsconf_dir *adir, 
+			    const char *apath, 
+			    struct afsconf_cell *acellInfo, char clones[])
 {
     register afs_int32 code;
     register int fd;
     char tbuffer[1024];
     register FILE *tf;
     register afs_int32 i;
-    
-    LOCK_GLOBAL_MUTEX
+
+    LOCK_GLOBAL_MUTEX;
     /* write ThisCell file */
     strcompose(tbuffer, 1024, apath, "/", AFSDIR_THISCELL_FILE, NULL);
 
     fd = open(tbuffer, O_RDWR | O_CREAT | O_TRUNC, 0666);
     if (fd < 0) {
-	UNLOCK_GLOBAL_MUTEX
+	UNLOCK_GLOBAL_MUTEX;
 	return errno;
     }
-    i = strlen(acellInfo->name);
+    i = (int)strlen(acellInfo->name);
     code = write(fd, acellInfo->name, i);
     if (code != i) {
-	UNLOCK_GLOBAL_MUTEX
+	UNLOCK_GLOBAL_MUTEX;
 	return AFSCONF_FAILURE;
     }
     if (close(fd) < 0) {
-	UNLOCK_GLOBAL_MUTEX
+	UNLOCK_GLOBAL_MUTEX;
 	return errno;
     }
-    
+
     /* make sure we have both name and address for each host, looking up other
-	if need be */
+     * if need be */
     code = VerifyEntries(acellInfo);
     if (code) {
-	UNLOCK_GLOBAL_MUTEX
+	UNLOCK_GLOBAL_MUTEX;
 	return code;
     }
 
@@ -130,33 +137,40 @@ afsconf_SetExtendedCellInfo(adir, apath, acellInfo, clones)
     strcompose(tbuffer, 1024, apath, "/", AFSDIR_CELLSERVDB_FILE, NULL);
     tf = fopen(tbuffer, "w");
     if (!tf) {
-	UNLOCK_GLOBAL_MUTEX
+	UNLOCK_GLOBAL_MUTEX;
 	return AFSCONF_NOTFOUND;
     }
-    fprintf(tf,	">%s	#Cell name\n", acellInfo->name);
-    for(i=0;i < acellInfo->numServers; i++) {
+    fprintf(tf, ">%s	#Cell name\n", acellInfo->name);
+    for (i = 0; i < acellInfo->numServers; i++) {
 	code = acellInfo->hostAddr[i].sin_addr.s_addr;	/* net order */
-	if (code == 0) continue;    /* delete request */
+	if (code == 0)
+	    continue;		/* delete request */
 	code = ntohl(code);	/* convert to host order */
-        if (clones && clones[i])
-            fprintf(tf, "[%d.%d.%d.%d]  #%s\n", (code>>24) & 0xff, (code>>16)&0xff, (code>>8)&0xff, code&0xff, acellInfo->hostName[i]);
-        else
-           fprintf(tf, "%d.%d.%d.%d    #%s\n", (code>>24) & 0xff, (code>>16)&0xff, (code>>8)&0xff, code&0xff, acellInfo->hostName[i]);
+	if (clones && clones[i])
+	    fprintf(tf, "[%d.%d.%d.%d]  #%s\n", (code >> 24) & 0xff,
+		    (code >> 16) & 0xff, (code >> 8) & 0xff, code & 0xff,
+		    acellInfo->hostName[i]);
+	else
+	    fprintf(tf, "%d.%d.%d.%d    #%s\n", (code >> 24) & 0xff,
+		    (code >> 16) & 0xff, (code >> 8) & 0xff, code & 0xff,
+		    acellInfo->hostName[i]);
     }
     if (ferror(tf)) {
 	fclose(tf);
-	UNLOCK_GLOBAL_MUTEX
+	UNLOCK_GLOBAL_MUTEX;
 	return AFSCONF_FAILURE;
     }
     code = fclose(tf);
 
     /* Reset the timestamp in the cache, so that
-       the CellServDB is read into the cache next time.
-       Resolves the lost update problem due to an inconsistent cache
-       */
-    if (adir) adir->timeRead = 0;
+     * the CellServDB is read into the cache next time.
+     * Resolves the lost update problem due to an inconsistent cache
+     */
+    if (adir)
+	adir->timeRead = 0;
 
-    UNLOCK_GLOBAL_MUTEX
-    if (code == EOF) return AFSCONF_FAILURE;
+    UNLOCK_GLOBAL_MUTEX;
+    if (code == EOF)
+	return AFSCONF_FAILURE;
     return 0;
 }
