@@ -11,7 +11,7 @@
 #include <afs/param.h>
 
 RCSID
-    ("$Header: /cvs/openafs/src/butc/dbentries.c,v 1.8.14.2 2007/10/30 15:16:38 shadow Exp $");
+    ("$Header: /cvs/openafs/src/butc/dbentries.c,v 1.8.14.5 2008/03/10 22:32:33 shadow Exp $");
 
 #include <sys/types.h>
 #ifdef AFS_NT40_ENV
@@ -310,13 +310,14 @@ waitDbWatcher()
     if (message) {
 	printf("Updating database - done\n");
     }
+    return;
 }
 
 #define MAXVOLUMESTOADD 100
 int addvolumes = 1;
 
-void
-dbWatcher()
+void *
+dbWatcher(void *unused)
 {
     dlqlinkP entryPtr;
     struct budb_dumpEntry *dumpPtr;
@@ -484,4 +485,5 @@ dbWatcher()
 	IOMGR_Sleep(2);
 #endif
     }
+    return NULL;
 }
