@@ -14,7 +14,7 @@
 
 #ifdef AFS_HPUX_ENV
 #define static_inline static __inline
-#elif defined(AFS_AIX_ENV)
+#elif defined(AFS_AIX_ENV) || defined(AFS_SGI_ENV)
 #define static_inline static
 #else
 #define static_inline static inline
@@ -37,8 +37,6 @@
  *   @retval 1  yes, state is mutually exclusive
  *
  * @note DEMAND_ATTACH_FS only
- *
- * @note should VOL_STATE_SALVSYNC_REQ be treated as exclusive?
  */
 static_inline int
 VIsExclusiveState(VolState state)
@@ -51,6 +49,7 @@ VIsExclusiveState(VolState state)
     case VOL_STATE_HDR_ATTACHING:
     case VOL_STATE_OFFLINING:
     case VOL_STATE_DETACHING:
+    case VOL_STATE_SALVSYNC_REQ:
     case VOL_STATE_VNODE_ALLOC:
     case VOL_STATE_VNODE_GET:
     case VOL_STATE_VNODE_CLOSE:
